@@ -17,6 +17,9 @@ class GeckoStructure:
     def __init__(self, on_set_value):
         self._status_block = b"\x00" * 1024
         self.accessors = {}
+        self.all_outputs = []
+        self.all_devices = []
+        self.user_demands = []
         self.had_at_least_one_block = False
         self._on_set_value = on_set_value
 
@@ -46,11 +49,11 @@ class GeckoStructure:
         self, handler: GeckoStatusBlockProtocolHandler, socket, sender
     ):
         if not self._next_expected == handler.sequence:
-            logger.warning(
+            logger.debug(
                 "Out-of-sequence status block segment %d - ignored", handler.sequence
             )
             if handler.next == 0:
-                logger.warning("Retry status block request")
+                logger.debug("Retry status block request")
                 self._next_expected = 0
                 self._status_block_segments = []
                 if not handler.retry(socket):
@@ -68,26 +71,17 @@ class GeckoStructure:
                 self.had_at_least_one_block = True
                 handler._should_remove_handler = True
 
-    def build_accessors(self, xmllist):
-        self.accessors = {
-            element.tag: GeckoStructAccessor(self, element)
-            for xml in xmllist
-            for element in xml.findall(
-                GeckoConstants.SPA_PACK_STRUCT_POS_ELEMENTS_XPATH
-            )
-        }
+    def build_accessors(self, config_class, log_class):
+        self.accessors = dict(config_class.accessors, **log_class.accessors)
         # Fix temperature accessors ...
-        temp_keys = {
-            element.tag
-            for xml in xmllist
-            for element in xml.findall(
-                GeckoConstants.SPA_PACK_STRUCT_WORD_TYPE_ELEMENTS_XPATH
-            )
-            if "temp" in element.tag.lower() or "setpoint" in element.tag.lower()
-        }
-        logger.debug("Temperature keys to decorate %s", temp_keys)
-        for key in temp_keys:
+        for key in [*config_class.temperature_keys, *log_class.temperature_keys]:
             self.accessors[key] = GeckoTemperatureDecorator(self, self.accessors[key])
+        # Get all outputs
+        self.all_outputs = config_class.output_keys
+        # Get collection of possible devices
+        self.all_devices = log_class.all_device_keys
+        # User devices are those that have a Ud in the tag name
+        self.user_demands = log_class.user_demand_keys
 
     def retry_request(
         self,
