@@ -2,6 +2,7 @@
 
 import sys, traceback
 import logging
+import datetime
 from .shared_command import GeckoCmd
 from .. import GeckoConstants, GeckoLocator, GeckoPump, VERSION
 
@@ -25,11 +26,6 @@ class GeckoShell(GeckoCmd):
         tested every setting and it might be that you prevent your spa pack from
         operating as it used to do.
 
-        Configuration is declared in the file SpaPackStruct.xml which is downloaded the
-        first time you run this program. Settings marked as RW="ALL" seem to indicate
-        that any process can write them, so you ought to be able to revert the settings
-        to their original ones.
-
         I strongly suggest dumping the configuration values with the "config" command
         and recording them somewhere safe.
 
@@ -162,6 +158,48 @@ class GeckoShell(GeckoCmd):
         for sensor in [*self.facade.sensors, *self.facade.binary_sensors]:
             print(sensor)
 
+    def monitor_get_states(self):
+
+        states = [
+            self.facade.water_heater,
+            *self.facade.pumps,
+            *self.facade.blowers,
+            *self.facade.lights,
+            *self.facade.reminders,
+            self.facade.water_care,
+            *self.facade.sensors,
+            *self.facade.binary_sensors,
+        ]
+
+        return [f"{state.monitor}" for state in states]
+
+    def monitor_compare_states(self, states):
+        local_state = self.monitor_get_states()
+        return local_state != states
+
+    def monitor_print_states(self, states):
+        print(f"{datetime.datetime.now()} : {' '.join(states)}")
+
+    def do_monitor(self, arg):
+        """Monitor the state of the managed spa outputting a new line for each change : monitor"""
+        del arg
+        if self.facade is None:
+            print("Must be connected to a spa")
+            return
+
+        print("Monitoring spa ... CTRL+C to stop")
+        current_state = []
+        while True:
+            try:
+                if self.monitor_compare_states(current_state):
+                    current_state = self.monitor_get_states()
+                    self.monitor_print_states(current_state)
+                self.facade.wait(1)
+            except KeyboardInterrupt:
+                print("")
+                print("Monitor stopped")
+                break
+
     @property
     def version_strings(self):
         """Get the version strings for the spa"""
@@ -183,41 +221,15 @@ class GeckoShell(GeckoCmd):
         for version_str in self.version_strings:
             print(version_str)
 
-    def do_config(self, arg):
-        """Display the configuration data from the spa : config"""
+    def do_accessors(self, arg):
+        """Display the data from the accessors : accessors """
         del arg
-        print("Configuration Settings")
-        print("======================")
+        print("Accessors")
+        print("=========")
         print("")
-        for element in self.facade.spa.config_xml.findall("./*"):
-            if "Pos" in element.attrib:
-                continue
-            print(element.tag)
-            print("-" * len(element.tag))
-            for child in element.findall("./*"):
-                print(
-                    "  {0}: {1}".format(
-                        child.tag, self.facade.spa.accessors[child.tag].value
-                    )
-                )
-            print("")
-
-    def do_live(self, arg):
-        """Display the live settings from the spa : live"""
-        del arg
-        print("Live Settings")
-        print("=============")
+        for key in self.facade.spa.accessors:
+            print("   {0}: {1}".format(key, self.facade.spa.accessors[key].value))
         print("")
-        for element in self.facade.spa.log_xml.findall("./*"):
-            print(element.tag)
-            print("-" * len(element.tag))
-            for child in element.findall("./*"):
-                print(
-                    "  {0}: {1}".format(
-                        child.tag, self.facade.spa.accessors[child.tag].value
-                    )
-                )
-            print("")
 
     def do_about(self, arg):
         """Display information about this client program and support library : about"""
@@ -248,7 +260,7 @@ class GeckoShell(GeckoCmd):
             key, val = arg.split("=")
             self.facade.spa.accessors[key].value = val
         except Exception:  # pylint: disable=broad-except
-            logger.exception("Exception handling setting %s=%s", key, val)
+            logger.exception("Exception handling 'set %s'", arg)
 
     def do_watercare(self, arg):
         """Set the active watercare mode to one of {0} : WATERCARE <mode>"""
